#!/usr/bin/env python
from setuptools import setup, find_packages
from pathlib import Path

this_dir = Path(__file__).parent
long_description = (this_dir / "README.md").read_text()

setup_info = dict(
    name='pyboil',
    python_requires=">=3.10",
    version='0.5.12',
    description='CLI script to initialize python packages',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Reed Schick",
    author_email='rns350@nyu.edu',
    url='https://github.com/rns350/pyinit',
    packages=find_packages(
        where='.', 
        include=['pyboil*']
    ),
    include_package_data=True,
    entry_points={
            'console_scripts': [
                'pyboil = pyboil.pyboil:launch',
            ]
        },
    install_requires=[],
    setup_requires=[],
    tests_require=['pytest']
)

setup(**setup_info)


import argparse

parser = argparse.ArgumentParser(
                    prog='Pyboil',
                    description='Initialize a basic python wheel package setup via cli script',
                    epilog='Get started fast!')

parser.add_argument(
    '-n', '--name', 
    dest="NAME",
    help="Specifies the name of the package to be initialized.",
    required=True
)

parser.add_argument(
    '-a', '--author',
    dest="AUTHOR",
    help="The author of this package (likely you!).",
    required=True
)

parser.add_argument(
    '-v', '--version',
    dest="VERSION",
    help="Version of the wheel to be placed in setup.py",
    default="0.1.0"
)

parser.add_argument(
    '-d', '--description',
    dest="DESCRIPTION",
    help="A short description of the package's purpose.",
    default="New python package!"
)

parser.add_argument(
    '-e', '--email',
    dest="EMAIL",
    help="email address for inquiries regarding the package.",
    default=""
)

parser.add_argument(
    '-u', '--url',
    dest="URL",
    help="Project website link (Github or Pypi).",
    default=""
)